@@ -17,6 +17,7 @@ our @EXPORT = (
        slurp
        spew
        textRenderTemplate
+       filePathNormalize
        /);
 
 our $VERSION = '0.01';
@@ -24,11 +25,11 @@ our $VERSION = '0.01';
 
 
 
-
 use Carp;
 use Data::Dumper;
 use File::Basename;
 use Path::Class;
+use File::Spec::Functions qw/ splitdir /;
 
 
 
@@ -96,6 +97,35 @@ sub spew {
 
 
 
+=head2 filePathNormalize($file)
+
+Return the normalized path of $file, i.e. with "dir/dir2/../dir3"
+becoming "dir/dir3".
+
+The path doesn't have to exist.
+
+=cut
+sub filePathNormalize {
+	my ($filePath) = @_;
+
+    my @aDirNew;
+    for my $dir (splitdir($filePath)) {
+        if($dir eq "..") {
+            ###TODO: @aDirNew or die("Malformed file ($filePath). Too many parent dirs ('sample_dir/../..')\n");
+            pop(@aDirNew);
+        }
+        else {
+            push(@aDirNew, $dir);
+        }
+    }
+    
+    return file(@aDirNew) . "";
+}
+
+
+
+
+
 =head2 textRenderTemplate($template, $rhParam)
 
 Replace the keys in $rhParam with the values in $rhParam, for
